<?php

namespace Drupal\phpmail_alter\Controller;

use Drupal\Core\Controller\ControllerBase;

/**
 * Defines the default Drupal mail backend, using PHP's native mail() function.
 */
class MailDebug extends ControllerBase {

  /**
   * Log errors.
   */
  public static function log($message, $mail_headers) {
    // Send error message.
    $subj = is_object($message['subject']) ? $message['subject']->render() : $message['subject'];
    $log_message = "{$message['to']} $subj <pre>$mail_headers</pre>";
    // Logs an error.
    \Drupal::logger('phpmail_alter')->error($log_message);
  }

  /**
   * Debug mail system.
   */
  public static function debug($message, $mail_headers, $mail_subject, $mail_body, $additional_headers) {
    // Debug mode.
    $config = \Drupal::config('phpmail_alter.settings');
    if ($config->get('debug')) {
      // Watchdog Log.
      $log = [
        'to' => $message['to'],
        'subject' => is_object($message['subject']) ? $message['subject']->render() : $message['subject'],
        'headers' => $mail_headers,
        'additional_headers' => $additional_headers,
      ];
      $log_message = "<pre>" . print_r($log, TRUE) . "</pre>";
      \Drupal::logger('phpmail_alter')->notice($log_message);

      // Debug output.
      if (\Drupal::moduleHandler()->moduleExists('devel')) {
        $debug_info = [
          'to' => $message['to'],
          'subject' => [
            'encoded' => is_object($mail_subject) ? $mail_subject->render() : $mail_subject,
            'decoded' => is_object($message['subject']) ? $message['subject']->render() : $message['subject'],
          ],
          'body' => $mail_body,
          'headers' => $mail_headers,
          'additional_headers' => $additional_headers,
        ];
        dsm($debug_info);
      }
    }
  }

}
